@@ -1,6 +1,7 @@
 /* bjnp-io.c
  *
  * (c) 2008, 2009 Louis Lagendijk
+ * (c) 2015 Markus Heinz
  *
  * This software is licensed under the terms of the GPL.
  * For details see file COPYING.
@@ -242,7 +243,7 @@ get_printer_address (char *resp_buf, char *address, char *name)
 
   bjnp_debug (LOG_INFO, "Found printer at ip address: %s\n", address);
 
-  /* do reverse name lookup, if hostname can not be fouund return ip-address */
+  /* do reverse name lookup, if hostname can not be found return ip-address */
 
   inet_aton (address, &ip_addr);
   myhost = gethostbyaddr (&ip_addr, sizeof (ip_addr), AF_INET);
@@ -299,6 +300,7 @@ bjnp_send_broadcast (struct in_addr local_addr, struct in_addr broadcast_addr,
 
   locaddr.sin_port = htons (BJNP_PORT_PRINT);
   locaddr.sin_addr = local_addr;
+  locaddr.sin_family = AF_INET;
   memset (locaddr.sin_zero, '\0', sizeof locaddr.sin_zero);
 
   if (bind
@@ -416,7 +418,7 @@ bjnp_discover_printers (struct printer_list *list)
 #else
   /* 
    * we do not have getifaddrs(), so there is no easy way to find all interfaces
-   * with teir broadcast addresses. We use a single global broadcast instead
+   * with their broadcast addresses. We use a single global broadcast instead
    */
   no_sockets = 0;
   broadcast.s_addr = htonl (INADDR_BROADCAST);
@@ -633,6 +635,7 @@ bjnp_get_printer_status (const int port_type, const char *device_uri,
 
   struct BJNP_command cmd;
   struct IDENTITY *id;
+  struct IDENTITY_NEW *idn;
   int resp_len;
   int id_len;
   char resp_buf[BJNP_RESP_MAX];
@@ -667,13 +670,18 @@ bjnp_get_printer_status (const int port_type, const char *device_uri,
 
   bjnp_hexdump (10, "Printer status:", resp_buf, resp_len);
 
-  id = (struct IDENTITY *) resp_buf;
-
-  id_len = ntohs (id->id_len) - sizeof (id->id_len);
-
   /* set status */
 
-  strncpy (status, id->id, id_len);
+  if (resp_buf[4] & 0x80) {
+    idn = (struct IDENTITY_NEW *) resp_buf;
+    id_len = ntohl (idn->cmd.payload_len);
+    strncpy (status, idn->id, id_len);
+  } else {
+    id = (struct IDENTITY *) resp_buf;
+    id_len = ntohs (id->id_len) - sizeof (id->id_len);
+    strncpy (status, id->id, id_len);
+  }
+
   status[id_len] = '\0';
 
   bjnp_debug (7, "Status = %s\n", status);
@@ -700,7 +708,7 @@ bjnp_get_id_from_printer_port (const int port, char *device_id)
    * is found, as the ordering may change from one call to the next.
    */
 
-  /* check if a successfull scan was done before, 
+  /* check if a successful scan was done before, 
      we will then not scan again so we do not mess up the ordering */
 
   if (num_printers == 0)
