@@ -1,7 +1,8 @@
 /* canon.c
  *
  * (c) 2006 Thierry MERLE <thierry.merle@free.fr>
- * (c) 2009 Louis Lagendijk
+ * (c) 2009, 2010 Louis Lagendijk
+ * (c) 2014 Markus Heinz
  *
  * Code taken from epson.c. Commands taken from CanonUtil 0.07 
  * (http://xwtools.automatix.de/)
@@ -23,10 +24,11 @@
 #include <unistd.h>
 
 #include "inklevel.h"
-#include "platform_specific.h"
+#include "devices.h"
 #include "util.h"
 #include "bjnp.h"
 #include "canon.h"
+#include "printer-io.h"
 
 #ifdef DEBUG
 /* for isprint(), for debug prints */
@@ -104,6 +106,10 @@ struct
      {{"CL",4,{CARTRIDGE_BLACK,CARTRIDGE_CYAN,
                CARTRIDGE_MAGENTA,CARTRIDGE_YELLOW}},
       {NULL,RESPONSE_INVALID,{}}}},
+    {"S750",
+     {{"CL",4,{CARTRIDGE_BLACK,CARTRIDGE_CYAN,
+               CARTRIDGE_MAGENTA,CARTRIDGE_YELLOW}},
+      {NULL,RESPONSE_INVALID,{}}}},
     {"i550",
      {{"VC",4,{CARTRIDGE_BLACK,CARTRIDGE_CYAN,
                CARTRIDGE_MAGENTA,CARTRIDGE_YELLOW}},
@@ -261,7 +267,7 @@ const static int MAX_NUMBER_OF_MODELS =
 
 /* Some Canon printers give a binary ink level indicator :
    LOW (attributed to 20% remaining) or not LOW, 100% remaining.
-   Some other printers give more precise indicator, 40 or 70% remaining. */
+   Some other printers give more precise indicator, 40% or 70% remaining. */
 #define LEVEL_LOW 20 /* 20% at which there is a warning */
 #define LEVEL_LOW_70 70
 #define LEVEL_LOW_40 40
@@ -282,11 +288,10 @@ const static int MAX_NUMBER_OF_MODELS =
 
 int get_ink_level_canon(const int port, const char* device_file, 
                         const int portnumber, struct ink_level *level) {
-  int fd;
   char cmdGetColors[] = 
     "SSR=BST,SFA,CHD,CIL,CIR,HRI,DBS,DWS,DOC,DSC,DJS,CTK,HCF;";
   char command[256];
-  int length;
+  int length = 0;
   int i = 0;
   char buffer[BUFLEN];
   char *indexDOC = NULL, *indexDWS = NULL, *indexCHD = NULL, *indexCIR = NULL;
@@ -306,9 +311,15 @@ int get_ink_level_canon(const int port, const char* device_file,
     indexCIR = strstr(buffer+2, "CIR:");
   } else {
     do {
-      fd = open_printer_device(port, device_file, portnumber);
-      if (fd < 0) {
-	return fd;
+      
+      /* Prepare printer descripton */
+      struct printer_descriptor desc;
+      desc.port = port;
+      desc.device_file = device_file;
+      desc.portnumber = portnumber;
+
+      if (open_wrapper(&desc) != PRINTER_SUCCESS) {
+	return ERROR;
       }
 
       /* Get colors command */
@@ -316,30 +327,55 @@ int get_ink_level_canon(const int port, const char* device_file,
 				 GET_STR_LENGTH(cmdGetColors),
 				 command);
 
-      i = write(fd, command, length);
-      if (i < length) {
+      if (write_wrapper(&desc, command, length, &i) != PRINTER_SUCCESS ||
+	  i < length) {
 
 #ifdef DEBUG
+
 	printf("Could not send command to printer\n");
+
 #endif
 
-	close(fd);
+	if (close_wrapper(&desc) != PRINTER_SUCCESS) {
+
+#ifdef DEBUG
+
+	  printf("Could not close printer\n");
+
+#endif
+
+	}
+
 	return COULD_NOT_WRITE_TO_PRINTER;
       }
 
-      length = read_from_printer(fd, buffer, BUFLEN, 0);
-      if (length <= 0) {
+      if (read_wrapper(&desc, buffer, BUFLEN, &length, 0) != PRINTER_SUCCESS ||
+	  (length <= 0)) {
 
 #ifdef DEBUG    
+
 	printf("Could not read from printer\n");
+
 #endif
-	close(fd);
+	
+	if (close_wrapper(&desc) != PRINTER_SUCCESS) {
+
+#ifdef DEBUG
+
+	  printf("Could not close printer\n");
+
+#endif
+
+	}
+
 	return COULD_NOT_READ_FROM_PRINTER;
       }
-      /* Insert a terminator so that whe can do string operations */
+
+      /* Insert a terminator so that we can do string operations */
       buffer[length] = '\0';
 
 #ifdef DEBUG
+
       printf("Command Response: \n");
       for (i = 0; i<length; i++) {
 	if (isprint(buffer[i])) 
@@ -348,6 +384,7 @@ int get_ink_level_canon(const int port, const char* device_file,
 	  printf("\\x%02x", (unsigned char) buffer[i]);
       }
       printf("\n");
+
 #endif
 
       /* The command response is a list of semicolons-separated TOKEN:VALUE.
@@ -357,8 +394,14 @@ int get_ink_level_canon(const int port, const char* device_file,
       indexDWS = strstr(buffer+2, "DWS:");
       indexCHD = strstr(buffer+2, "CHD:");
       indexCIR = strstr(buffer+2, "CIR:");
-    
-      close(fd);
+      
+      if (close_wrapper(&desc) != PRINTER_SUCCESS) {
+
+#ifdef DEBUG
+	  printf("Could not close printer\n");
+#endif
+
+      }
 
     } while (!indexDOC && !indexDWS && !indexCHD && !indexCHD && --retry);
   }
@@ -366,7 +409,9 @@ int get_ink_level_canon(const int port, const char* device_file,
   if (!indexDOC && !indexDWS && !indexCHD && !indexCHD) {
 	  
 #ifdef DEBUG
+
     printf("Could not parse output from printer\n");
+
 #endif
 
     return COULD_NOT_PARSE_RESPONSE_FROM_PRINTER;
@@ -376,8 +421,8 @@ int get_ink_level_canon(const int port, const char* device_file,
     decodeCIR(indexCIR,level);
   else {
     /* decodeCHD -> Cartridge type <-
-       this fuction will update the level structure with default values depending
-       of the printer definition */
+       this function will update the level structure with default values 
+       depending of the printer definition */
     if(indexCHD) decodeCHD(indexCHD,level);
     /* At this state, we must have a valid status.
        otherwise that means the printer is not supported */
@@ -590,17 +635,18 @@ static void decodeCIR(char *s, struct ink_level *level) {
 	{CARTRIDGE_YELLOW, ",Y="}, 
 	{CARTRIDGE_MAGENTA, ",M="}, 
 	{CARTRIDGE_CYAN, ",C="}, 
-	{CARTRIDGE_COLOR, ",CL="}
+	{CARTRIDGE_COLOR, ",CL="},
+	{CARTRIDGE_PG, ",GY="}
       };
-#define NO_CARTRIDGES 9
+#define NO_CARTRIDGES 10
 
   char *cart_level;	/* inklevel reported by printer */
   int i;		/* loop variable for cartridges table */
-  int level_index =0;	/* next avaiable position in level table */
+  int level_index =0;	/* next available position in level table */
 
   /* skip CIR tag */
   s+=3;
-  
+
   /* replace ":" by "," to ensure that all subtags start with "," */
   s[0]=',';
 
