@@ -1,6 +1,6 @@
 /* inklevel.h
  *
- * (c) 2003, 2004, 2005, 2006, 2007, 2009 Markus Heinz
+ * (c) 2003, 2004, 2005, 2006, 2007, 2009, 2014, 2015 Markus Heinz
  *
  * This software is licensed under the terms of the GPL.
  * For details see file COPYING.
@@ -9,18 +9,14 @@
 #ifndef INKLEVEL_H
 #define INKLEVEL_H
 
-#ifdef DEBUG
-#include <stdio.h> /* for the debug printfs */
-#endif
-
 /* public interface */
 
 /* Values for port */
 
 #define PARPORT 1
 #define USB 2
-#define CUSTOM_PARPORT 3
-#define CUSTOM_USB 4
+#define CUSTOM_PARPORT 3 /* not used */
+#define CUSTOM_USB 4 /* deprecated */
 #define BJNP 5
 #define CUSTOM_BJNP 6
 
@@ -42,10 +38,12 @@
 #define COULD_NOT_READ_FROM_PRINTER -13
 #define COULD_NOT_PARSE_RESPONSE_FROM_PRINTER -14
 #define COULD_NOT_GET_CREDIT -15
-#define DEV_CUSTOM_USB_INACCESSIBLE -16
+#define DEV_CUSTOM_USB_INACCESSIBLE -16 /* deprecated */
 #define BJNP_URI_INVALID -17
 #define BJNP_INVALID_HOSTNAME -18
 
+/* Limits */
+
 #define MODEL_NAME_LENGTH 100
 #define MAX_CARTRIDGE_TYPES 40
 
@@ -94,14 +92,18 @@
 #define INDEX_TYPE 0
 #define INDEX_LEVEL 1
 
-struct ink_level {
+/* Data structure for ink level */
+
+typedef struct ink_level {
   char model[MODEL_NAME_LENGTH];
   unsigned short status;
   unsigned short levels[MAX_CARTRIDGE_TYPES][2];
-};
+} ink_level;
 
-int get_ink_level(const int port, const char*device_file, 
-                  const int portnumber, struct ink_level *level);
+/* Public interface of libinklevel */
+
+int get_ink_level(const int port, const char *device_file, 
+		  const int portnumber, struct ink_level *level);
 char *get_version_string(void);
 
 #endif
