@@ -1,6 +1,6 @@
 /* util.c
  *
- * (c) 2003, 2004, 2009 Markus Heinz
+ * (c) 2003, 2004, 2009, 2014 Markus Heinz
  *
  * This software is licensed under the terms of the GPL.
  * For details see file COPYING.
@@ -8,6 +8,7 @@
 
 #include "config.h"
 
+#include <stdio.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/poll.h>
@@ -26,7 +27,7 @@ int read_from_printer(int fd, void *buf, size_t bufsize, int nonblocking) {
 
   memset(buf, 0, bufsize);
 
-  if (nonblocking) {
+  if (nonblocking != 0) {
     fcntl(fd, F_SETFL, O_NONBLOCK | fcntl(fd, F_GETFL));
   }
 
@@ -180,7 +181,7 @@ int my_axtoi(char* t) {
   return r;
 }
 
-/* This function converts a string containig a three digit decimal number
+/* This function converts a string containing a three digit decimal number
  * to an int 
  */
 
