@@ -6,6 +6,9 @@
  * For details see file COPYING.
  */
 
+#ifndef UTIL_H
+#define UTIL_H
+
 #include "internal.h"
 #include "inklevel.h"
 
@@ -15,3 +18,5 @@ int my_atoi(char *t);
 void tokenize_device_id(const char *string, char tags[NR_TAGS][BUFLEN]);
 char *get_tag_value(char tags[NR_TAGS][BUFLEN], char *tag);
 int get_tag_index(char tags[NR_TAGS][BUFLEN], char *tag);
+
+#endif
